require 'spec_helper'

describe Dumptruck::Truck do
  describe '.new' do
    let(:dump) { Dumptruck::Truck.new({
      :username => "root",
      :password => "d33ps0uth@local",
    })}

    it 'has a username' do
      expect(dump.username).to eq("root")
    end

    it 'has a password' do
      expect(dump.password).not_to eq(nil)
    end

    it 'has an output directory' do
      expect(dump.output_dir).to eq("/tmp")
    end

    it 'has a filename' do
      expect(dump.filename).not_to eq(nil)
    end

    it 'raises error if no loads are added to dump' do
      Cocaine::CommandLine.path = nil
      begin
        dump.dump
      rescue Dumptruck::NothingLoaded => e
        expect(e.message).to eq "You haven't loaded anything!"
      end
    end

    it 'no mysqldump raises error' do
      Cocaine::CommandLine.path = nil
      dump.load({ database: 'test' })
      begin
        dump.dump
      rescue Dumptruck::MysqlDumpNotFound => e
        expect(e.message).to eq "Could not find the `mysqldump` command."
      end
    end

    it "creates a Load object" do
      dump.load({database: "test"})
    end

    it 'generates the mysqldump command' do
      dump.load({database: "test"})
      expect(dump.command).to eq(["mysqldump -u #{dump.username} --password=#{dump.password} -h localhost -P 3306 --single-transaction --opt --skip-comments test"])
    end
  end
end
